powered by
This function plots the runs by team against all teams in in powerplay, middle and death overs
teamRunsAcrossOversAllOppnAllMatches(matches,t1,plot=1)
none
The dataframe of the matches
The team for which the runs is required
Plot=1 (static), Plot=2(interactive)
Tinniam V Ganesh
https://cricsheet.org/ https://gigadom.in/ https://github.com/tvganesh/yorkrData/
getBatsmanDetails getBowlerWicketDetails batsmanDismissals getTeamBattingDetails
getBatsmanDetails
getBowlerWicketDetails
batsmanDismissals
getTeamBattingDetails
if (FALSE) { # Plot tne match worm plot teamRunsAcrossOversAllOppnAllMatches(matches,'England') }
Run the code above in your browser using DataLab