if (FALSE) {
# Get all matches between India with all oppositions
matches <-getAllMatchesAllOpposition("India",dir="../data/",save=TRUE)
# This can also be loaded from saved file
# load("allMatchesAllOpposition-India.RData")
# Top batsman is displayed in descending order of runs
teamRunsSRPlotAllOppnAllMatches(matches,theTeam="India")
# The best England players scorecard against India is shown
teamRunsSRPlotAllOppnAllMatches(matches,theTeam="England",plot=1)
}
Run the code above in your browser using DataLab